<?xml version="1.0" encoding="UTF-8"?>
<!-- VZ807v1.0_VALXSLT_546u3, 14-09-2023 -->
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:vbt="http://ei.vektis.nl/vz/basis/v1_0"
xmlns:vz807="http://ei.vektis.nl/vz/vz807/v1_0"
xmlns:vz808="http://ei.vektis.nl/vz/vz808/v1_0" >


 	<xsl:import href="rc0350.xslt"/>	
 	<xsl:import href="rc8028.xslt"/> 
 	<xsl:import href="rc8986.xslt"/>	
 	<xsl:import href="rc9188.xslt"/>	
	<xsl:import href="rc9189.xslt"/>
	<xsl:import href="rc9190.xslt"/>	
	<xsl:import href="rc9191.xslt"/>	
	<xsl:import href="rc9192.xslt"/>	
	<xsl:import href="rc9193a.xslt"/>	
	<xsl:import href="rc9193b.xslt"/>	
	<xsl:import href="rc9196.xslt"/>	
	<xsl:import href="rc9200.xslt"/>	
 	
 	
	<!-- Uitvoer is vz808 bericht met Retourcodes. -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
	
	<xsl:variable name="Berichtcode" select="//vz807:Bericht/vz807:Header/vbt:Berichtcode" />
	<xsl:variable name="BerichtSoort" select="//vz807:Bericht/vz807:Header/vbt:BerichtSoort"/> 
	<xsl:variable name="Verzenddatum" select="translate(//vz807:Bericht/vz807:Header/vbt:Verzenddatum, '-', '')"/>
	<xsl:variable name="FinancieelJaar" select="translate(//vz807:Bericht/vz807:Context/vz807:FinancieelJaar, '-', '')"/>						


	<!-- Controleer op errors in de Header -->
	<!-- retourcode 8028: Soort bericht ontbreekt of is onjuist -->
	<xsl:variable name="rc8028">
		<xsl:call-template name="rc8028">
			<xsl:with-param name="BerichtSoort" select="$BerichtSoort" />
		</xsl:call-template>
	</xsl:variable>

	<!-- retourcode 8986: Verzenddatum moet kleiner zijn dan of gelijk zijn aan de huidige datum. -->
	<xsl:variable name="rc8986">
		<xsl:call-template name="rc8986">
			<xsl:with-param name="Verzenddatum" select="$Verzenddatum" />
			<xsl:with-param name="BerichtSoort" select="$BerichtSoort" />
		</xsl:call-template>
	</xsl:variable>

	<xsl:template match="//vz807:Bericht">
		<vz808:Bericht>
			<xsl:attribute name="xsi:schemaLocation">http://ei.vektis.nl/vz/vz808/v1_0 vz808_547.xsd</xsl:attribute>
			
			<xsl:choose>

				<!-- Geen errors in de Header, dan hele bericht als retour -->
				<xsl:when test="$rc8028='' and $rc8986=''">

					<xsl:apply-templates select="vz807:Header"/>
					<xsl:apply-templates select="vz807:Context"/>
					<xsl:apply-templates select="vz807:Overzicht"/>
					<xsl:apply-templates select="vz807:Specificatieregels"/>  
  				</xsl:when>

				<!-- Wel errors in de Header, dan alleen Header als retour -->
				<xsl:otherwise>
					<xsl:apply-templates select="vz807:Header"/>
				</xsl:otherwise>
			</xsl:choose>
				
		</vz808:Bericht>
	</xsl:template>	
		
	<xsl:template match="vz807:Header">
		<vz808:Header>
		
			<xsl:apply-templates select="vbt:BerichtSoort" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:CrediteurOrgaan"/>
			<xsl:apply-templates select="vbt:BuitenlandsVerbindingsOrgaan"/>
			<xsl:apply-templates select="vbt:Verzenddatum" mode="copy-if-exists"/>
			<vz808:BerichtCode>547</vz808:BerichtCode>
			<xsl:apply-templates select="vz807:BerichtVersie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz807:BerichtSubVersie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz807:DeclaratieReferentienummer" mode="copy-if-exists"/>
			
  	       	<vz808:Retourcodes>
					
				<xsl:copy-of select="$rc8028"/>
				<xsl:copy-of select="$rc8986"/>
					
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc8028='' and $rc8986=''">
					<vbt:Retourcode>0200</vbt:Retourcode>
				</xsl:if>
				
			</vz808:Retourcodes>
  	       	
		</vz808:Header>
	</xsl:template>
		
	<xsl:template match="vz807:Context">
		<vz808:Context>
			
			<xsl:apply-templates select="vz807:FinancieelJaar" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz807:KalenderHalfJaar" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz807:CodeWet" mode="copy-if-exists"/>
			
  	       	<vz808:Retourcodes>
				
				<!-- retourcode 9188: FinancieelJaar ontbreekt of is onjuist. -->
				<xsl:variable name="rc9188">
					<xsl:call-template name="rc9188">
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum" />
						<xsl:with-param name="FinancieelJaar" select="$FinancieelJaar"/>						
					</xsl:call-template>
				</xsl:variable>
				
				<!-- retourcode 9189: Verzenddatum ligt buiten Kalenderhalfjaar van FinancieelJaar. -->
				<xsl:variable name="rc9189">
					<xsl:call-template name="rc9189">
						<xsl:with-param name="FinancieelJaar" select="$FinancieelJaar"/>
						<xsl:with-param name="KalenderHalfJaar" select="//vz807:Bericht/vz807:Context/vz807:KalenderHalfJaar"/>				
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
					</xsl:call-template>
				</xsl:variable>				
					
				<xsl:copy-of select="$rc9188"/>
				<xsl:copy-of select="$rc9189"/>
					
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc9188='' and $rc9189=''">
					<vbt:Retourcode>0200</vbt:Retourcode>
				</xsl:if>
				
			</vz808:Retourcodes>
  	       	
		</vz808:Context>
	</xsl:template>	
	
	<xsl:template match="vz807:Overzicht">
		<vz808:Overzicht>
			
			<xsl:apply-templates select="vz807:TotaalAantalSpecificaties" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz807:TotaalBedragSpecificaties"/>
			
  	       	<vz808:Retourcodes>
				<!-- retourcode is altijd 0200, er is voor berichtcode 546 geen controleregel voor Overzicht-->
					<vbt:Retourcode>0200</vbt:Retourcode>
			</vz808:Retourcodes>
  	       	
		</vz808:Overzicht>
	</xsl:template>		
	
	<xsl:template match="vz807:Specificatieregels">
		<vz808:Specificatieregels>
			<xsl:apply-templates select="vz807:Specificatieregel"/> 
		</vz808:Specificatieregels>
	</xsl:template>	

	<xsl:template match="vz807:Specificatieregel">
		<vz808:Specificatieregel>
			
			<xsl:apply-templates select="vz807:DebiteurOrgaan"/>
			<xsl:apply-templates select="vz807:Referenties"/>
			<xsl:apply-templates select="vz807:Persoonsgegevens"/>
			<xsl:apply-templates select="vz807:DocumentDatRechtAantoont"/>
			<xsl:apply-templates select="vz807:TotaalBedrag"/>				
			<xsl:apply-templates select="vz807:Uitkeringen"/>	
  	       	<vz808:Retourcodes>
				
				<!-- retourcode 0350: Geboortedatum ontbreekt of is onjuist. -->
				<xsl:variable name="rc0350">
					<xsl:call-template name="rc0350">
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
						<xsl:with-param name="Geboortedatum" select="translate(//vz807:Bericht/vz807:Specificatieregels/vz807:Specificatieregel/vz807:Persoonsgegevens/vbt:Geboortedatum, '-', '')"/>						
					</xsl:call-template>
				</xsl:variable>
				
				<!-- retourcode 9190: Afgiftedatum ontbreekt of is onjuist. -->
				<xsl:variable name="rc9190">
					<xsl:call-template name="rc9190">
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
						<xsl:with-param name="AfgiftedatumSpecifiek" select="translate(vz807:DocumentDatRechtAantoont/vz807:SpecifiekDocument/vz807:Afgiftedatum, '-', '')"/>		
						<xsl:with-param name="AfgiftedatumOverig" select="translate(vz807:DocumentDatRechtAantoont/vz807:OverigDocument/vz807:Afgiftedatum, '-', '')"/>				
					</xsl:call-template>
				</xsl:variable>
				
				<!-- retourcode 9191: Begindatum DocumentPeriode ontbreekt of is onjuist. -->
				<xsl:variable name="rc9191">
					<xsl:call-template name="rc9191">
						<xsl:with-param name="OverigDocument" select="vz807:DocumentDatRechtAantoont/vz807:OverigDocument"/>
						<xsl:with-param name="BegindatumOverig" select="translate(vz807:DocumentDatRechtAantoont/vz807:OverigDocument/vz807:GeldigheidRechtPeriode/vbt:Begindatum, '-', '')"/>	
						<xsl:with-param name="SpecifiekDocument" select="vz807:DocumentDatRechtAantoont/vz807:SpecifiekDocument"/>
						<xsl:with-param name="BegindatumSpecifiek" select="translate(vz807:DocumentDatRechtAantoont/vz807:SpecifiekDocument/vz807:GeldigheidRechtPeriode/vbt:Begindatum, '-', '')"/>					
					</xsl:call-template>
				</xsl:variable>
				
				<!-- retourcode 9192: Einddatum periode uitkeringen moet gelijk zijn aan of later zijn dan de begindatum periode uitkeringen. -->
				<xsl:variable name="rc9192">
					<xsl:call-template name="rc9192">
						<xsl:with-param name="Begindatum" select="translate(vz807:Uitkeringen/vz807:Periode/vbt:Begindatum, '-', '')"/>	
						<xsl:with-param name="Einddatum" select="translate(vz807:Uitkeringen/vz807:Periode/vbt:Einddatum, '-', '')"/>						
					</xsl:call-template>
				</xsl:variable>
				
				<!-- retourcode 9193: Einddatum DocumentPeriode ontbreekt of is onjuist. -->
				<xsl:variable name="rc9193a">
					<xsl:call-template name="rc9193a">
						<xsl:with-param name="TypePeriodeOverig" select="vz807:DocumentDatRechtAantoont/vz807:OverigDocument/vz807:TypePeriode"/>	
						<xsl:with-param name="EinddatumOverig" select="translate(vz807:DocumentDatRechtAantoont/vz807:OverigDocument/vz807:GeldigheidRechtPeriode/vbt:Einddatum, '-', '')"/>	
						<xsl:with-param name="TypePeriodeSpecifiek" select="vz807:DocumentDatRechtAantoont/vz807:SpecifiekDocument/vz807:TypePeriode"/>
						<xsl:with-param name="EinddatumSpecifiek" select="translate(vz807:DocumentDatRechtAantoont/vz807:SpecifiekDocument/vz807:GeldigheidRechtPeriode/vbt:Einddatum, '-', '')"/>
					</xsl:call-template>
				</xsl:variable>
				
				<!-- retourcode 9193: Einddatum DocumentPeriode ontbreekt of is onjuist. -->
				<xsl:variable name="rc9193b">
					<xsl:call-template name="rc9193b">
						<xsl:with-param name="EHICDocument" select="vz807:DocumentDatRechtAantoont/vz807:EHICDocument"/>
						<xsl:with-param name="Einddatum" select="translate(vz807:DocumentDatRechtAantoont/vz807:EHICDocument/vz807:GeldigheidRechtPeriode/vbt:Einddatum, '-', '')"/>				
					</xsl:call-template>
				</xsl:variable>
				
				<!-- retourcode 9196: Ten minste moet MedischeZorgkosten, Medicijnkosten, Tandartskosten, LangdurigeZorgkosten, Ziekenhuisopnameskosten of OverigeKosten voorkomen. -->
				<xsl:variable name="rc9196">
					<xsl:variable name="Uitkeringen" select="vz807:Uitkeringen"/>
					<xsl:if test="($Uitkeringen !='')">
						<xsl:call-template name="rc9196">
							<xsl:with-param name="MedischeZorgkosten" select="vz807:Uitkeringen/vz807:Kosten/vbt:MedischeZorgkosten"/>
							<xsl:with-param name="Medicijnkosten" select="vz807:Uitkeringen/vz807:Kosten/vbt:Medicijnkosten"/>
							<xsl:with-param name="Tandartskosten" select="vz807:Uitkeringen/vz807:Kosten/vbt:Tandartskosten"/>
							<xsl:with-param name="LangdurigeZorgkosten" select="vz807:Uitkeringen/vz807:Kosten/vbt:LangdurigeZorgkosten"/>
							<xsl:with-param name="Ziekenhuisopnameskosten" select="vz807:Uitkeringen/vz807:Kosten/vbt:Ziekenhuisopnameskosten"/>
							<xsl:with-param name="OverigeKosten" select="vz807:Uitkeringen/vz807:Kosten/vbt:OverigeKosten"/>
						</xsl:call-template>
					</xsl:if>	
				</xsl:variable>
				
				<!-- retourcode 9200: Einddatum periode uitkeringen moet gelijk zijn aan of vroeger zijn dan de verzenddatum. -->
				<xsl:variable name="rc9200">
					<xsl:call-template name="rc9200">
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>	
						<xsl:with-param name="Einddatum" select="translate(vz807:Uitkeringen/vz807:Periode/vbt:Einddatum, '-', '')"/>						
					</xsl:call-template>
				</xsl:variable>
				
				<xsl:copy-of select="$rc0350"/>
				<xsl:copy-of select="$rc9190"/>				
				<xsl:copy-of select="$rc9191"/>
				<xsl:copy-of select="$rc9192"/>		
				<xsl:copy-of select="$rc9193a"/>		
				<xsl:copy-of select="$rc9193b"/>		
				<xsl:copy-of select="$rc9196"/>		
				<xsl:copy-of select="$rc9200"/>	
					
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc0350='' and $rc9190='' and $rc9191='' and $rc9192='' and $rc9193a='' and $rc9193b='' and $rc9196='' and $rc9200=''">
					<vbt:Retourcode>0200</vbt:Retourcode>
				</xsl:if>
				
			</vz808:Retourcodes>
  	       	
		</vz808:Specificatieregel>
	</xsl:template>		
	
	<xsl:template match="vbt:CrediteurOrgaan">	
		<vbt:CrediteurOrgaan>
			<xsl:apply-templates select="vbt:Orgaancode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Landcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Naam" mode="copy-if-exists"/>
		</vbt:CrediteurOrgaan>
	</xsl:template>
	
	<xsl:template match="vbt:BuitenlandsVerbindingsOrgaan">	
		<vbt:BuitenlandsVerbindingsOrgaan>
			<xsl:apply-templates select="vbt:Orgaancode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Landcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Naam" mode="copy-if-exists"/>
		</vbt:BuitenlandsVerbindingsOrgaan>
	</xsl:template>

	<xsl:template match="vz807:DebiteurOrgaan">	
		<vz808:DebiteurOrgaan>
			<xsl:apply-templates select="vbt:Orgaancode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Landcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Naam" mode="copy-if-exists"/>
		</vz808:DebiteurOrgaan>
	</xsl:template>
	
	<xsl:template match="vz807:TotaalBedragSpecificaties">	
		<vz808:TotaalBedragSpecificaties>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Valuta" mode="copy-if-exists"/>
		</vz808:TotaalBedragSpecificaties>
	</xsl:template>		
	
	<xsl:template match="vz807:Referenties">	
		<vz808:Referenties>
			<xsl:apply-templates select="vz807:DeclaratieregelReferentienummer" mode="copy-if-exists"/>
		</vz808:Referenties>
	</xsl:template>	

	<xsl:template match="vz807:Persoonsgegevens">	
		<vz808:Persoonsgegevens>
			<xsl:apply-templates select="vbt:PINVerzekeringsland" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:PINWoonlandofVerblijfsland" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Familienaam" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:FamilienaamGeboorte" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Voornamen" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:VoornamenGeboorte" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Geboortedatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:GeslachtCode" mode="copy-if-exists"/>
		</vz808:Persoonsgegevens>
	</xsl:template>		
	
	<xsl:template match="vz807:DocumentDatRechtAantoont">	
		<vz808:DocumentDatRechtAantoont>
			<xsl:apply-templates select="vz807:EHICDocument"/>
			<xsl:apply-templates select="vz807:SpecifiekDocument"/>
			<xsl:apply-templates select="vz807:OverigDocument"/>
		</vz808:DocumentDatRechtAantoont>
	</xsl:template>		
	
	<xsl:template match="vz807:EHICDocument">	
		<vz808:EHICDocument>
			<xsl:apply-templates select="vz807:Documentcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz807:EHICNummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz807:GeldigheidRechtPeriode"/>
		</vz808:EHICDocument>
	</xsl:template>		
	
	<xsl:template match="vz807:SpecifiekDocument">	
		<vz808:SpecifiekDocument>
			<xsl:apply-templates select="vz807:Documentcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz807:Afgiftedatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz807:TypePeriode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz807:GeldigheidRechtPeriode"/>
		</vz808:SpecifiekDocument>
	</xsl:template>	
	
	<xsl:template match="vz807:OverigDocument">	
		<vz808:OverigDocument>
			<xsl:apply-templates select="vz807:Documentcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz807:Afgiftedatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz807:TypePeriode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz807:GeldigheidRechtPeriode"/>
		</vz808:OverigDocument>
	</xsl:template>	

	<xsl:template match="vz807:GeldigheidRechtPeriode">	
		<vz808:GeldigheidRechtPeriode>
			<xsl:apply-templates select="vbt:Begindatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Einddatum" mode="copy-if-exists"/>
		</vz808:GeldigheidRechtPeriode>
	</xsl:template>		
		
	<xsl:template match="vz807:TotaalBedrag">	
		<vz808:TotaalBedrag>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Valuta" mode="copy-if-exists"/>
		</vz808:TotaalBedrag>
	</xsl:template>	
	
	<xsl:template match="vz807:Uitkeringen">	
		<vz808:Uitkeringen>
			<xsl:apply-templates select="vz807:SoortPrestatie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz807:Periode"/>
			<xsl:apply-templates select="vz807:Kosten"/>
		</vz808:Uitkeringen>
	</xsl:template>		

	<xsl:template match="vz807:Periode">	
		<vz808:Periode>
			<xsl:apply-templates select="vbt:Begindatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Einddatum" mode="copy-if-exists"/>
		</vz808:Periode>
	</xsl:template>		
		
	<xsl:template match="vz807:Kosten">	
		<vz808:Kosten>
			<xsl:apply-templates select="vbt:MedischeZorgkosten"/>
			<xsl:apply-templates select="vbt:Medicijnkosten"/>
			<xsl:apply-templates select="vbt:Tandartskosten"/>
			<xsl:apply-templates select="vbt:LangdurigeZorgkosten"/>
			<xsl:apply-templates select="vbt:Ziekenhuisopnameskosten"/>
			<xsl:apply-templates select="vbt:OverigeKosten"/>
		</vz808:Kosten>
	</xsl:template>		

	<xsl:template match="vbt:MedischeZorgkosten">	
		<vbt:MedischeZorgkosten>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
		</vbt:MedischeZorgkosten>
	</xsl:template>	
	
		<xsl:template match="vbt:Medicijnkosten">	
		<vbt:Medicijnkosten>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
		</vbt:Medicijnkosten>
	</xsl:template>	
	
		<xsl:template match="vbt:Tandartskosten">	
		<vbt:Tandartskosten>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
		</vbt:Tandartskosten>
	</xsl:template>	
	
		<xsl:template match="vbt:LangdurigeZorgkosten">	
		<vbt:LangdurigeZorgkosten>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
		</vbt:LangdurigeZorgkosten>
	</xsl:template>	
	
	<xsl:template match="vbt:Periode">	
		<vbt:Periode>
			<xsl:apply-templates select="vbt:Begindatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Einddatum" mode="copy-if-exists"/>
		</vbt:Periode>
	</xsl:template>	
	
		<xsl:template match="vbt:Ziekenhuisopnameskosten">	
		<vbt:Ziekenhuisopnameskosten>
			<xsl:apply-templates select="vbt:UitkeringZiekenhuisopname"/>
		</vbt:Ziekenhuisopnameskosten>
	</xsl:template>

	<xsl:template match="vbt:UitkeringZiekenhuisopname">	
		<vbt:UitkeringZiekenhuisopname>
			<xsl:apply-templates select="vbt:Periode"/>
			<xsl:apply-templates select="vbt:Kosten"/>
		</vbt:UitkeringZiekenhuisopname>
	</xsl:template>		
	
	<xsl:template match="vbt:Kosten">	
		<vbt:Kosten>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
		</vbt:Kosten>
	</xsl:template>	

		<xsl:template match="vbt:OverigeKosten">	
		<vbt:OverigeKosten>
			<xsl:apply-templates select="vbt:UitkeringOverig"/>
		</vbt:OverigeKosten>
	</xsl:template>

	<xsl:template match="vbt:UitkeringOverig">	
		<vbt:UitkeringOverig>
			<xsl:apply-templates select="vbt:Beschrijving" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Kosten"/>
		</vbt:UitkeringOverig>
	</xsl:template>	

	<!-- Copy template: als een enkel element voorkomt is, wordt deze gekopieerd in de opgegeven namespace -->
	<xsl:template match="vz807:*" mode="copy-if-exists">
		<xsl:param name="NameSpacePrefix" select="'vz808:'"/>
		<xsl:if test=".">
			<xsl:element name="{concat($NameSpacePrefix,local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<xsl:template match="*[not(starts-with(name(), 'vz807:'))]" mode="copy-if-exists">
        <xsl:if test=".">
            <xsl:element name="{name()}">
				<xsl:value-of select="text()"/>
            </xsl:element>
        </xsl:if>
	</xsl:template>

</xsl:stylesheet>